MethodChannelCvNativeClient class

An implementation of CvNativeClientPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getClipboardData() → Future<Map<String, String>?>
get clipboard data from the clipboard asynchronously.
override
getClipboardDataMimeTypes() → Future<List<String>>
Retrieves the mime types of the content currently available in the clipboard asynchronously.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setClipboardData(Map<String, String> params) → Future<bool>
Writes the provided text to the clipboard asynchronously.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited