CvNativeClientPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • CvNativeClientPlatform
Implementers

Constructors

CvNativeClientPlatform()
Constructs a CvNativeClientPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getClipboardData() → Future<Map<String, String>?>
get clipboard data from the clipboard asynchronously.
getClipboardDataMimeTypes() → Future<List<String>>
Retrieves the mime types of the content currently available in the clipboard asynchronously.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setClipboardData(Map<String, String> params) → Future<bool>
Writes the provided text to the clipboard asynchronously.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ CvNativeClientPlatform
The default instance of CvNativeClientPlatform to use.
getter/setter pair