CvClipboardData class final

A class that represents the data that can be copied to the clipboard.

Annotations

Constructors

CvClipboardData({required String plainText, required String htmlText})
Constructs a CvClipboardData.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
htmlText → String
The HTML text to copy to the clipboard.
final
plainText → String
The plain text to copy to the clipboard.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited