Clipboard class

Represents a clipboard.

Implemented types
Available extensions

Constructors

Clipboard()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read() → Future<Iterable<ClipboardItem>>

Available on Clipboard, provided by the ClipboardExtension extension

Reads the clipboard items asynchronously.
toString() → String
A string representation of this object.
inherited
write(Iterable<ClipboardItem> data) → Future<void>

Available on Clipboard, provided by the ClipboardExtension extension

Writes the given data to the clipboard asynchronously.

Operators

operator ==(Object other) → bool
The equality operator.
inherited